import {select, csv, scaleLinear, extent, scaleTime, line, max, min,
        axisLeft, axisBottom, format, curveBasis} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = dd => {
  const xValue = d => d.timestamp;
  const xLabel = 'Time';
  const yValue = d => d.temperature;
  const yLabel = 'Temperature';
  const circleRadius = 10;
  const margin = {top:50, right:50, bottom:100, left: 150};
  const innerwidth = width-margin.right-margin.left;
  const innerheight = height-margin.top-margin.bottom
  
  const xScale = scaleTime()
  	.domain([min(dd, xValue), max(dd, xValue)])
  	.range([0, innerwidth])
  	.nice();
  
  
  
  const yScale = scaleLinear()
  	.domain(extent(dd, yValue))
  	.range([innerheight, 0])
  	.nice();
  
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerheight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerwidth)
  	.tickPadding(5);
  
  const yAxisG = g.append('g').call(yAxis);
   
  yAxisG.selectAll('.domain')
  		.remove();
  
  
   yAxisG.append('text')
  	.attr('y',-50)
  	.attr('x', -innerheight/2)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.style('text-anchor', 'middle')
  	.text(yLabel);
  	 
  const xAxisG = g.append('g').call(xAxis)
 		.attr('transform', `translate(0, ${innerheight})`);
  
  
 xAxisG.selectAll('.domain').remove();
  
 xAxisG.append('text')
  	.attr('y',50)
  	.attr('x', innerwidth /2)
  	.attr('fill', 'black')
  	.text(xLabel);
  
  const lineGenerator = line()
  	.x(pick => xScale(xValue(pick)))
  	.y(pick => yScale(yValue(pick)))
  	.curve(curveBasis);
  
  	
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', lineGenerator(dd))
  

  
  
  g.append('text')
  	.attr('y', -10)
		.text('Temperature in San Francisco');
  
};

	

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data => { console.log(data)
  data.forEach(d => {
    d.temperature = +d.temperature;
    d.timestamp = new Date(d.timestamp);
  })
	render(data)
});



